aboutsummaryrefslogtreecommitdiffstats
path: root/drivers
diff options
context:
space:
mode:
authorLinus Torvalds <torvalds@linux-foundation.org>2019-07-11 11:17:09 -0700
committerLinus Torvalds <torvalds@linux-foundation.org>2019-07-11 11:17:09 -0700
commita131c2bf165684315f606fdd88cf80be22ba32f3 (patch)
treefa03e8c179095946e776c8664859a899eba2c822 /drivers
parentMerge git://git.kernel.org/pub/scm/linux/kernel/git/davem/net-next (diff)
parentRevert "ACPICA: Update table load object initialization" (diff)
downloadlinux-dev-a131c2bf165684315f606fdd88cf80be22ba32f3.tar.xz
linux-dev-a131c2bf165684315f606fdd88cf80be22ba32f3.zip
Merge tag 'acpi-5.3-rc1-2' of git://git.kernel.org/pub/scm/linux/kernel/git/rafael/linux-pm
Pull ACPI fix from Rafael Wysocki: "Revert a recent ACPICA commit causing systems to hang at boot time" * tag 'acpi-5.3-rc1-2' of git://git.kernel.org/pub/scm/linux/kernel/git/rafael/linux-pm: Revert "ACPICA: Update table load object initialization"
Diffstat (limited to 'drivers')
-rw-r--r--drivers/acpi/acpica/exconfig.c16
-rw-r--r--drivers/acpi/acpica/tbxfload.c10
2 files changed, 17 insertions, 9 deletions
diff --git a/drivers/acpi/acpica/exconfig.c b/drivers/acpi/acpica/exconfig.c
index 58c04d706723..587aeeeb5070 100644
--- a/drivers/acpi/acpica/exconfig.c
+++ b/drivers/acpi/acpica/exconfig.c
@@ -174,9 +174,12 @@ acpi_ex_load_table_op(struct acpi_walk_state *walk_state,
return_ACPI_STATUS(status);
}
- /* Complete the initialization/resolution of new objects */
+ /* Complete the initialization/resolution of package objects */
- acpi_ns_initialize_objects();
+ status = acpi_ns_walk_namespace(ACPI_TYPE_PACKAGE, ACPI_ROOT_OBJECT,
+ ACPI_UINT32_MAX, 0,
+ acpi_ns_init_one_package, NULL, NULL,
+ NULL);
/* Parameter Data (optional) */
@@ -434,11 +437,12 @@ acpi_ex_load_op(union acpi_operand_object *obj_desc,
return_ACPI_STATUS(status);
}
- /* Complete the initialization/resolution of new objects */
+ /* Complete the initialization/resolution of package objects */
- acpi_ex_exit_interpreter();
- acpi_ns_initialize_objects();
- acpi_ex_enter_interpreter();
+ status = acpi_ns_walk_namespace(ACPI_TYPE_PACKAGE, ACPI_ROOT_OBJECT,
+ ACPI_UINT32_MAX, 0,
+ acpi_ns_init_one_package, NULL, NULL,
+ NULL);
/* Store the ddb_handle into the Target operand */
diff --git a/drivers/acpi/acpica/tbxfload.c b/drivers/acpi/acpica/tbxfload.c
index 86f1693f6d29..ef8f8a9f3c9c 100644
--- a/drivers/acpi/acpica/tbxfload.c
+++ b/drivers/acpi/acpica/tbxfload.c
@@ -297,11 +297,15 @@ acpi_status acpi_load_table(struct acpi_table_header *table)
status = acpi_tb_install_and_load_table(ACPI_PTR_TO_PHYSADDR(table),
ACPI_TABLE_ORIGIN_EXTERNAL_VIRTUAL,
FALSE, &table_index);
- if (ACPI_SUCCESS(status)) {
- /* Complete the initialization/resolution of new objects */
+ if (ACPI_SUCCESS(status)) {
+ /* Complete the initialization/resolution of package objects */
- acpi_ns_initialize_objects();
+ status = acpi_ns_walk_namespace(ACPI_TYPE_PACKAGE,
+ ACPI_ROOT_OBJECT,
+ ACPI_UINT32_MAX, 0,
+ acpi_ns_init_one_package,
+ NULL, NULL, NULL);
}
return_ACPI_STATUS(status);